@@ -6,7 +6,7 @@ no  warnings 'uninitialized';
 
 use vars qw($VERSION);
 
-$VERSION = '1.32';
+$VERSION = '1.33';
 
 =head1 NAME
 
@@ -151,7 +151,7 @@ use WeakRef;
 
 use vars qw($VERSION);
 
-$VERSION = '1.32';
+$VERSION = '1.33';
 
 =head1 NAME
 
@@ -347,109 +347,6 @@ sub _get_id {
     shift->__get_id( shift );
 }
 
-sub _add_parent {
-    my( $self, $parent_ref, $child_ref ) = @_;
-    my $parent_class = ref( $parent_ref );
-    my $child_class = ref( $child_ref );
-    return unless $parent_class && $child_class;
-
-    my $parent_id = $self->__get_id( $parent_ref );
-    my $child_id = $self->__get_id( $child_ref );
-    
-    if( $child_class eq 'Yote::Array' ) {
-        push @{$child_ref->[4]}, $parent_id;
-    }
-    elsif( $child_class eq 'Array' ) {
-        my $tied = tied @$child_ref;
-        if( $tied ) {
-            push @{$tied->[4]}, $parent_id;
-        }
-    }
-    elsif( $child_class eq 'Yote::Hash' ) {
-        push @{$child_ref->[4]}, $parent_id;
-    }
-    elsif( $child_class eq 'HASH' ) {
-        my $tied = tied %$child_ref;
-        if( $tied ) {
-            push @{$tied->[4]}, $parent_id;
-        }
-    }
-    else {
-        push @{$child_ref->{_PARENTS}}, $parent_id;
-    }
-} #_add_parent
-
-
-sub _remove_from_parent {
-    my( $self, $parent_ref, $child_ref ) = @_;
-    my $parent_class = ref( $parent_ref );
-    my $child_class = ref( $child_ref );
-    return unless $parent_class && $child_class;
-
-    my $parent_id = $self->__get_id( $parent_ref );
-    my $child_id = $self->__get_id( $child_ref );
-
-    my $ref;
-    if( $child_class eq 'Yote::Array' ) {
-        $ref = $child_ref->[4];
-    }
-    elsif( $child_class eq 'Array' ) {
-        my $tied = tied @$child_ref;
-        if( $tied ) {
-            $ref = $tied->[4];
-        }
-    }
-    elsif( $child_class eq 'Yote::Hash' ) {
-        $ref = $child_ref->[4];
-    }
-    elsif( $child_class eq 'HASH' ) {
-        my $tied = tied %$child_ref;
-        if( $tied ) {
-            $ref = $tied->[4];
-        }
-    }
-    else {
-        $ref = $child_ref->{_PARENTS};
-    }
-    if( $ref ) {
-        for( my $i=0; $i<@$ref; $i++ ) {
-            if( $ref->[$i] == $parent_id ) {
-                splice @$ref, $i, 1;
-                return;
-            }
-        }
-    }
-} #_remove_from_parent
-
-sub _get_parents {
-    my( $self, $child_ref ) = @_;
-
-    my $child_class = ref( $child_ref );
-    return unless $child_class;
-
-    if( $child_class eq 'Yote::Array' ) {
-        return @{$child_ref->[4]};
-    }
-    elsif( $child_class eq 'Array' ) {
-        my $tied = tied @$child_ref;
-        if( $tied ) {
-            return @{$tied->[4]};
-        }
-    }
-    elsif( $child_class eq 'Yote::Hash' ) {
-        return @{$child_ref->[4]};
-    }
-    elsif( $child_class eq 'HASH' ) {
-        my $tied = tied %$child_ref;
-        if( $tied ) {
-            return @{$tied->[4]};
-        }
-    }
-    else {
-        return @{$child_ref->{_PARENTS}};
-    }
-} #_get_parents
-
 sub __get_id {
     my( $self, $ref ) = @_;
     my $class = ref( $ref );
@@ -676,7 +573,7 @@ no  warnings 'uninitialized';
 
 use vars qw($VERSION);
 
-$VERSION = '1.32';
+$VERSION = '1.33';
 
 #
 # The string version of the yote object is simply its id. This allows
@@ -701,9 +598,6 @@ sub absorb {
     for my $key ( sort keys %$data ) {
         my $item = $data->{ $key };
         $self->{DATA}{$key} = $obj_store->_xform_in( $item );
-        if( ref $item ) {
-            push @{$item->{_PARENTS}}, $self;
-        }
     }
     $obj_store->_dirty( $self, $self->{ID} );
 
@@ -722,7 +616,6 @@ sub set {
     my $inval = $self->{STORE}->_xform_in( $val );
     if( $self->{DATA}{$fld} ne $inval ) {
         $self->{STORE}->_dirty( $self, $self->{ID} );
-        $self->{STORE}->_add_parent( $self, $val );
     }
 
     
@@ -744,7 +637,6 @@ sub get {
         if( ref( $default ) ) {
             # this must be done to make sure the reference is saved for cases where the reference has not yet made it to the store of things to save
             $self->{STORE}->_dirty( $default->{STORE}->_get_id( $default ) );
-            $self->{STORE}->_add_parent( $self, $default );
         }
         $self->{STORE}->_dirty( $self, $self->{ID} );
         $self->{DATA}{$fld} = $self->{STORE}->_xform_in( $default );
@@ -950,14 +842,14 @@ use Tie::Array;
 
 use vars qw($VERSION);
 
-$VERSION = '1.32';
+$VERSION = '1.33';
 
 sub TIEARRAY {
     my( $class, $obj_store, $id, @list ) = @_;
     my $storage = [];
 
     # once the array is tied, an additional data field will be added
-    # so obj will be [ $id, $storage, $obj_store, $parentlist ]
+    # so obj will be [ $id, $storage, $obj_store ]
     my $obj = bless [$id,$storage,$obj_store], $class;
     for my $item (@list) {
         push( @$storage, $item );
@@ -1043,12 +935,12 @@ use Tie::Hash;
 
 use vars qw($VERSION);
 
-$VERSION = '1.32';
+$VERSION = '1.33';
 
 sub TIEHASH {
     my( $class, $obj_store, $id, %hash ) = @_;
     my $storage = {};
-    # after $obj_store is a list reference of parent ids
+    # after $obj_store is a list reference of
     #                 id, data, store
     my $obj = bless [ $id, $storage,$obj_store ], $class;
     for my $key (keys %hash) {
@@ -1118,7 +1010,7 @@ use constant {
 
 use vars qw($VERSION);
 
-$VERSION = '1.32';
+$VERSION = '1.33';
 
 #
 # This the main index and stores in which table and position
@@ -1302,6 +1194,6 @@ __END__
        under the same terms as Perl itself.
 
 =head1 VERSION
-       Version 1.32  (May 1, 2016))
+       Version 1.33  (May 1, 2016))
 
 =cut
